@@ -168,8 +168,8 @@ void JackTrip::setupAudio(
 {
     // Check if mAudioInterface has already been created or not
     if (mAudioInterface
-        != NULL) {  // if it has been created, disconnet it from JACK and delete it
-        cout << "WARINING: JackAudio interface was setup already:" << endl;
+        != NULL) {  // if it has been created, disconnect it from JACK and delete it
+        cout << "WARNING: JackAudio interface was setup already:" << endl;
         cout << "It will be erased and setup again." << endl;
         cout << gPrintSeparator << endl;
         closeAudio();
@@ -377,15 +377,20 @@ void JackTrip::setupRingBuffers()
                 new RingBuffer(audio_output_slot_size, mBufferQueueLength);
             mPacketHeader->setBufferRequiresSameSettings(true);
         } else if (mBufferStrategy == 3) {
-            qDebug() << "experimental buffer strategy 3 -- regulator with PLC";
-            mSendRingBuffer =
-                new RingBuffer(audio_input_slot_size, gDefaultOutputQueueLength);
+            cout << "Using experimental buffer strategy " << mBufferStrategy
+                 << "-- Regulator with PLC" << endl;
+
             mReceiveRingBuffer =
-                new Regulator(mSampleRate, mNumAudioChansOut, mAudioBitResolution,
-                              mAudioBufferSize, mBufferQueueLength);
+                new Regulator(mNumAudioChansOut, mAudioBitResolution, mAudioBufferSize,
+                              mBufferQueueLength, mBroadcastQueueLength);
             // bufStrategy 3, mBufferQueueLength is in integer msec not packets
 
             mPacketHeader->setBufferRequiresSameSettings(false);  // = asym is default
+
+            if (0 < mBroadcastQueueLength) {
+                mAudioInterface->enableBroadcastOutput();
+            }
+
         } else {
             cout << "Using JitterBuffer strategy " << mBufferStrategy << endl;
             if (0 > mBufferQueueLength) {
@@ -522,7 +527,7 @@ void JackTrip::startProcess(
                          "clientPingToServerStart"
                       << std::endl;
         if (clientPingToServerStart()
-            == -1) {  // if error on server start (-1) we return inmediatly
+            == -1) {  // if error on server start (-1) we return immediately
             stop(QStringLiteral(
                 "Peer Address has to be set if you run in CLIENTTOPINGSERVER mode"));
             return;
@@ -536,7 +541,7 @@ void JackTrip::startProcess(
                 << "  JackTrip:startProcess case SERVERPINGSERVER before serverStart"
                 << std::endl;
         if (serverStart(true)
-            == -1) {  // if error on server start (-1) we return inmediatly
+            == -1) {  // if error on server start (-1) we return immediately
             stop();
             return;
         }
@@ -651,8 +656,7 @@ void JackTrip::onStatTimer()
             << now.toLocal8Bit().constData() << " "
             << getPeerAddress().toLocal8Bit().constData()
             << " send: " << send_io_stat.underruns << "/" << send_io_stat.overflows
-            << " Pull underruns: "
-            << recv_io_stat.underruns  // pullStat->lastPlcUnderruns;
+            << " Glitches: " << recv_io_stat.underruns  // pullStat->lastPlcUnderruns;
 #define INVFLOATFACTOR 0.001
             << "\nPUSH -- SD avg/last: " << setw(5)
             << INVFLOATFACTOR * recv_io_stat.overflows  // pushStat->longTermStdDev;
@@ -679,8 +683,9 @@ void JackTrip::onStatTimer()
             //                     << "/" << recv_io_stat.overflows << " prot: " <<
             //                     pkt_stat.lost << "/"
             //                     << pkt_stat.outOfOrder << "/" << pkt_stat.revived
-            << " \n tot: "
-            << pkt_stat.tot
+            << " \n tot: " << pkt_stat.tot << " \t tol: " << setw(5)
+            << INVFLOATFACTOR * recv_io_stat.autoq_corr << " \t dsp (last): " << setw(5)
+            << INVFLOATFACTOR * recv_io_stat.autoq_rate
             //                     << " sync: " << recv_io_stat.level << "/"
             //                     << recv_io_stat.buf_inc_underrun << "/"
             //                     << recv_io_stat.buf_inc_compensate << "/"
@@ -826,7 +831,7 @@ void JackTrip::receivedDataTCP()
     mTcpClient.close();  // Close the socket
     // cout << "TCP Socket Closed!" << endl;
 
-    // If we sent authentication data, check if our authentication attempt was succesfull
+    // If we sent authentication data, check if our authentication attempt was successful
     if (mUseAuth && udp_port > 65535) {
         QString error_message;
         if (udp_port == Auth::WRONGCREDS) {
@@ -854,7 +859,7 @@ void JackTrip::receivedDataTCP()
     }
 
     if (gVerboseFlag)
-        cout << "Connection Succesfull!" << endl;
+        cout << "Connection Successful!" << endl;
 
     // Set with the received UDP port
     // ------------------------------
@@ -967,7 +972,7 @@ void JackTrip::receivedDataUDP()
     //     We reply to the same port the peer sent the packets from
     //     This way we can go through NAT
     //     Because of the NAT traversal scheme, the portn need to be
-    //     "symetric", e.g.:
+    //     "symmetric", e.g.:
     //     from Client to Server : src = 4474, dest = 4464
     //     from Server to Client : src = 4464, dest = 4474
     // no -- all are the same -- 4464
@@ -1045,13 +1050,17 @@ void JackTrip::stop(const QString& errorMessage)
     mHasShutdown = true;
     std::cout << "Stopping JackTrip..." << std::endl;
 
-    // Stop The Sender
-    mDataProtocolSender->stop();
-    mDataProtocolSender->wait();
+    if (mDataProtocolSender != nullptr) {
+        // Stop The Sender
+        mDataProtocolSender->stop();
+        mDataProtocolSender->wait();
+    }
 
-    // Stop The Receiver
-    mDataProtocolReceiver->stop();
-    mDataProtocolReceiver->wait();
+    if (mDataProtocolReceiver != nullptr) {
+        // Stop The Receiver
+        mDataProtocolReceiver->stop();
+        mDataProtocolReceiver->wait();
+    }
 
     // Stop the audio processes
     // mAudioInterface->stopProcess();
@@ -1116,6 +1125,7 @@ int JackTrip::serverStart(bool timeout, int udpTimeout)  // udpTimeout unused
             mEndTime = udpTimeout;
         }
         mTimeoutTimer.setInterval(mSleepTime);
+        mTimeoutTimer.disconnect();
         connect(&mTimeoutTimer, &QTimer::timeout, this, &JackTrip::udpTimerTick);
         mTimeoutTimer.start();
     }
@@ -1210,6 +1220,7 @@ int JackTrip::clientPingToServerStart()
         mElapsedTime = 0;
         mEndTime     = 5000;  // Timeout after 5 seconds.
         mTimeoutTimer.setInterval(mSleepTime);
+        mTimeoutTimer.disconnect();
         connect(&mTimeoutTimer, &QTimer::timeout, this, &JackTrip::tcpTimerTick);
         mTimeoutTimer.start();
     }
@@ -1297,7 +1308,7 @@ active address local_addr.sin_port = htons(bind_port); //set bind port
   ::setsockopt(sock_fd, SOL_SOCKET, SO_REUSEADDR, &one, sizeof(one));
 #endif
 #if defined ( __APPLE__ )
-  // This option is not avialable on Linux, and without it MAC OS X
+  // This option is not available on Linux, and without it MAC OS X
   // has problems rebinding a socket
   ::setsockopt(sock_fd, SOL_SOCKET, SO_REUSEPORT, &one, sizeof(one));
 #endif
